function picopic_move_servo(servo,width,speed);
% function picopic_move_servo(servo,width,speed);
% 
% Example usage:
% picopic_move_servo(servo,width,speed);
% servo object
% width (in the servo's range)
% speed (1-255 low-high rates, with 0 as a max_rate)

if (width>servo.max_pulse)
    disp('Please don''t kill your servo, or adjust the servo object parameters, you tried to go over the max!');
    break;
end
if (width<servo.min_pulse)
    disp('Please don''t kill your servo, or adjust the servo object parameters, you tried to go under the min!');
    break;
end
highpos=floor(width/256);
lowpos=mod(width,256);

if (speed<0)
    disp('The speed cannot be negative!');
    break;
end
if (speed>255)
    disp('The speed cannot be above 255!');
    break;
end

s0=serial(servo.port,'BaudRate',servo.port_speed);
fopen(s0);
% whos
% disp(['#' address '-' channel '-' highpos '-' lowpos '-' speed '#'])
address=char(servo.address);
channel=char(servo.channel);
highpos=char(highpos);
lowpos=char(lowpos);
speed=char(speed);
fwrite(s0,[address,channel,highpos,lowpos,speed],'uchar');

%fprintf(s0,'%2x%2x%2x%2x%2x',[120 10 50 0 1]); %$78 $0A $06 $72 $00
% fwrite(s0,address,'uchar');
% fwrite(s0,channel,'uchar');
% fwrite(s0,highpos,'uchar');
% fwrite(s0,lowpos,'uchar');
% fwrite(s0,speed,'uchar');

fclose(s0);
clear s0;

% [Address], [1-20], [Position (H)], [Position (L)], [Speed]
% Where: [Address]: This first byte refers to the address of PicoPic.
%   The default is 120 and you should change it only if you anticipate other controllers
%   to be on the serial bus. Address numbers are from 1 to 255. Zero is reserved and is not
%   a valid address. [1-20]: This second byte is the servo number. Since PicoPic can control
%   20 servos, valid numbers are from 1 to 20 (0x01  0x14).
%   [Position (H)], [Position (L)]:
%   These 2 bytes specify the positioning of the servo. Recall that the servo command requires
%   2 bytes for positioning. By default, the range of acceptable values, are between 750 and 2200.
%   You can extend this range by issuing a command 14 (see command 14) and rebooting PicoPic.
%   After the execution of a Extend Pulse command, the range of acceptable pulse widths will be
%   between 500 and 2400s. This feature was added as security measure. Be aware that you can
%   damage your servo gears if you exceed the limitation of your servos.
%   Use with caution. If both Position (H) and Position (L) are zeros, the port will become
%   a digital port and the level will be at ground (0v). If Position (H) is zero and Position
%   (L) is 1, the port will become a digital port and the level will be at logic high (+5v)
%   To disable a servo, you can set the ports signal to logic low (0v). This will cause 
%   the servo to be turned off (except a small amount of current for the internal electronics).
%   [Speed]: This byte is the speed that we want the servos to move. A 1 is the slowest and 255
%   is the fastest (besides zero).
%
%
%   SERVO EXAMPLE 1: To clarify these points, assume that the address of your PicoPic is the
%   default 120 (decimal) and that you want PicoPic to send 1.65 ms pulses to servo number 17
%   and that you wish to move this servo as fast as it can move. The command packet would be
%   as follows, $78 $11 $06 $72 $00 Here, the first byte of our packet ($78) is the hex equivalent
%   of the decimal number 120, PicoPics default address. The second byte ($11) is the hex value 
%   of decimal number 17 for port # 17 command. The third and fourth bytes ($06, $72) are the
%   positioning (timing) of this servo in 16 bit hex format with the most significant byte
%   (MSB) first. Since all servo timings are 16 bits, we have to send 2 bytes to fulfill this
%   requirement. If both of these bytes are set to zero, then the signal to the servo is driven
%   low. This effectively turns off the servo. The fifth and final byte ($00) is the speed of
%   which we want the servo to move. There are 256 speeds available (0 to 255). Speed of 1 is 
%   the slowest and 255 is the fastest of the delays. The speed of 0 indicates no delays and moves
%   the servos as fast as they can move.